@@ -1,4 +1,4 @@
-#include <float.h>
+#include <cfloat>
 
 #include "general.h"
 #include "error.h"
@@ -7,6 +7,8 @@
 #include "regtree.h"
 #include "utils.h"
 
+using namespace std ;
+
 int featureTree::predictR(marray<int> &predictedClass, marray<double> &predictedProb) {
 	int i, j;
 	// initialize return arrays
